@@ -623,6 +623,8 @@ class IP:
                 self.dut_core = get_core(self.dut_fsoc_full_name, True)
             else:
                 self.dut.resolve()
+                if self.dut.target_ip_model.sub_type == "vivado":
+                    self.dut_ip_type = "vivado"
                 self.dut_vendor = self.dut.target_ip_model.vendor
         for dep in self.dependencies:
             dep.resolve()
