@@ -34,9 +34,9 @@ def main(ip_str):
             dut_ip = cache.get_ip(ip.dut.vendor, ip.dut.target_ip)
             if dut_ip == None:
                 common.fatal(f"Cannot find DUT IP '{ip.dut.vendor}/{ip.dut.target_ip}'")
-            if ip.dut_ip_type != "":
-                if ip.dut.target_ip_model.sub_type == "vivado":
-                    clean_ip(dut_ip)
+            #if ip.dut_ip_type != "":
+            #    if ip.dut.target_ip_model.sub_type == "vivado":
+            #        clean_ip(dut_ip)
 
 
 def clean_core(core):
