@@ -640,9 +640,14 @@ def do_cmp_vivado_project(ip, deps, sim_job, sub_ip=False, owner_ip=None):
     sim_str = common.get_simulator_short_name(sim_job.simulator)
     
     if sub_ip:
-        eff_ip_dir_name = f"{owner_ip.vendor}__{owner_ip.name}"
-        cmp_out = cfg.sim_output_dir + "/" + sim_str + "/cmp_out/" + eff_ip_dir_name
-        sim_out = cfg.sim_output_dir + "/" + sim_str + "/sim_wd/"  + eff_ip_dir_name
+        if sim_job.is_regression:
+            eff_ip_dir_name = f"{owner_ip.vendor}__{owner_ip.name}__{sim_job.regression_name}__{sim_job.regression_timestamp}"
+            cmp_out = cfg.sim_output_dir + "/" + sim_str + "/regr_wd/" + eff_ip_dir_name
+            sim_out = cfg.sim_output_dir + "/" + sim_str + "/regr_wd/" + eff_ip_dir_name
+        else:
+            eff_ip_dir_name = f"{owner_ip.vendor}__{owner_ip.name}"
+            cmp_out = cfg.sim_output_dir + "/" + sim_str + "/cmp_out/" + eff_ip_dir_name
+            sim_out = cfg.sim_output_dir + "/" + sim_str + "/sim_wd/"  + eff_ip_dir_name
         work_name = owner_ip.name
     else:
         work_name = ip.name
@@ -707,8 +712,10 @@ def do_elab(ip, sim_job, wd):
         arg_list.append("--log "  + elaboration_log_path)
         arg_list.append("-s "     + ip.name)
         arg_list.append("-L "     + ip.name + "=" + ip_cmp_path)
-        if ip.has_dut and ip.dut_ip_type == "vivado":
-            arg_list.append("-L " + ip.dut.target_ip_model.vproj_name)
+        #if ip.has_dut and ip.dut_ip_type == "vivado":
+        #    arg_list.append("-L " + ip.dut.target_ip_model.vproj_name)
+        #    for construct in ip.dut.target_ip_model.hdl_src_top_constructs:
+        #        arg_list.append(construct)
         for construct in ip.hdl_src_top_constructs:
             if "." in construct:
                 arg_list.append(construct)
@@ -1126,6 +1133,7 @@ def dut_elab_to_arg_list(ip, sim_job):
         if dut_ip.sub_type == "vivado":
             if sim_job.simulator != common.simulators_enum.VIVADO:
                 common.fatal("Vivado Projects are currently only compatible with the Vivado simulator.")
+            args.append("-L " + dut_ip.vproj_name)
             for construct in dut_ip.hdl_src_top_constructs:
                 args.append(f"{construct}")
             for lib in dut_ip.vproj_libs:
