@@ -519,6 +519,9 @@ def main(ip_str, target_name, regression, simulator, dry_mode):
     if deps_to_install > 0:
         common.fatal(f"You must first install this IP's dependencies ({deps_to_install}): `mio install {name}`")
     
+    if simulator == None:
+        simulator = cfg.default_simulator
+    
     common.create_dir(cfg.regr_results_dir)
     test_suite = scan_target_ip_for_test_suite(ip, simulator)
     if test_suite.target_name != "*":
